try_poweroff

Function try_poweroff 

pub fn try_poweroff(code: ExitCode)
Attempts to power off the system using an architecture-specific mechanism.

On x86, this function attempts to power off the system through QEMU’s ISA debug-exit device if QEMU was detected during initialization. Otherwise, it does nothing and returns.