pub fn try_poweroff(code: ExitCode)Expand description
Attempts to power off the system using an architecture-specific mechanism.
On x86, this function attempts to power off the system through QEMU’s ISA debug-exit device if QEMU was detected during initialization. Otherwise, it does nothing and returns.